@@ -135,11 +135,13 @@ class Acme::Client
     @kid ||= account.kid
   end
 
-  def new_order(identifiers:, not_before: nil, not_after: nil)
+  def new_order(identifiers:, not_before: nil, not_after: nil, profile: nil, replaces: nil)
     payload = {}
     payload['identifiers'] = prepare_order_identifiers(identifiers)
     payload['notBefore'] = not_before if not_before
     payload['notAfter'] = not_after if not_after
+    payload['profile'] = profile if profile
+    payload['replaces'] = replaces if replaces
 
     response = post(endpoint_for(:new_order), payload: payload)
     arguments = attributes_from_order_response(response)
@@ -222,6 +224,15 @@ class Acme::Client
     response.success?
   end
 
+  def renewal_info(certificate:)
+    cert_id = Acme::Client::Util.ari_certificate_identifier(certificate)
+    renewal_info_url = URI.join(endpoint_for(:renewal_info).to_s + '/', cert_id).to_s
+
+    response = get(renewal_info_url)
+    attributes = attributes_from_renewal_info_response(response)
+    Acme::Client::Resources::RenewalInfo.new(self, **attributes)
+  end
+
   def get_nonce
     http_client = Acme::Client::HTTPClient.new_connection(url: endpoint_for(:new_nonce), options: @connection_options)
     response = http_client.head(nil, nil)
@@ -253,6 +264,10 @@ class Acme::Client
     directory.external_account_required
   end
 
+  def profiles
+    directory.profiles
+  end
+
   private
 
   def load_directory
@@ -299,7 +314,8 @@ class Acme::Client
       [:finalize_url, 'finalize'],
       [:authorization_urls, 'authorizations'],
       [:certificate_url, 'certificate'],
-      :identifiers
+      :identifiers,
+      :profile
     )
 
     attributes[:url] = response.headers[:location] if response.headers[:location]
@@ -314,6 +330,16 @@ class Acme::Client
     extract_attributes(response.body, :status, :url, :token, :type, :error, :validated)
   end
 
+  def attributes_from_renewal_info_response(response)
+    attributes = extract_attributes(
+      response.body,
+      [:suggested_window, 'suggestedWindow'],
+      [:explanation_url, 'explanationURL']
+    )
+    attributes[:retry_after] = response.headers['retry-after'] if response.headers['retry-after']
+    attributes
+  end
+
   def extract_attributes(input, *attributes)
     attributes
       .map {|fields| Array(fields) }
